@@ -1,15 +1,20 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2019 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Mail-Box.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Box::File;
 use vars '$VERSION';
-$VERSION = '2.117';
+$VERSION = '3.007';
 
 use base 'Mail::Box';
 
 use strict;
+use warnings;
+
 use filetest 'access';
 
 use Mail::Box::File::Message;
@@ -32,7 +37,7 @@ use POSIX ':unistd_h';
 use IO::File;
 
 my $windows;
-BEGIN { $windows = $^O =~ m/mswin32|cygwin/i }
+BEGIN { $windows = $^O =~ m/mswin32/i }
 
 
 my $default_folder_dir = exists $ENV{HOME} ? $ENV{HOME} . '/Mail' : '.';
